--------   All functions below this line will only load if you are playing the corresponding class   --------
if not SpellFlashAddon.WARRIOR then return end




-- Will return false if Sunder Armor is stacked less than 5 times on the target.
function SpellFlashAddon.isSunderFull(unit)
	if SpellFlashAddon.GetDebuffStack((GetSpellInfo(7386))--[["Sunder Armor"]], unit) == 5 then
		return true
	end
	return false
end

function SpellFlashAddon.isSunder(unit)
	return SpellFlashAddon.checkDebuff((GetSpellInfo(7386))--[["Sunder Armor"]],unit)
end

function SpellFlashAddon.isRend(unit)
	return SpellFlashAddon.checkDebuff((GetSpellInfo(772))--[["Rend"]],unit,1)
end

function SpellFlashAddon.isHamstring(unit)
	return SpellFlashAddon.checkDebuff((GetSpellInfo(1715))--[["Hamstring"]],unit)
end

function SpellFlashAddon.isPiercingHowl(unit)
	return SpellFlashAddon.checkDebuff((GetSpellInfo(12323))--[["Piercing Howl"]],unit)
end

function SpellFlashAddon.isDemoralizingShout(unit)
	return SpellFlashAddon.checkDebuff((GetSpellInfo(1160))--[["Demoralizing Shout"]],unit)
end

function SpellFlashAddon.isThunderClap(unit)
	return SpellFlashAddon.checkDebuff((GetSpellInfo(6343))--[["Thunder Clap"]],unit)
end

function SpellFlashAddon.isDisarm(unit)
	return SpellFlashAddon.checkDebuff((GetSpellInfo(676))--[["Disarm"]],unit)
end





-- Will return true if you are in the queried stance.
-- Example: SpellFlashAddon.WARRIOR.CheckStance("Battle Stance")
-- The example above will return true if you are currently in the Battle Stance.
function SpellFlashAddon.WARRIOR.CheckStance(stance)
	return SpellFlashAddon.isForm(stance)
end

function SpellFlashAddon.isBattleStance()
	return SpellFlashAddon.isForm((GetSpellInfo(2457))--[["Battle Stance"]])
end

function SpellFlashAddon.isDefensiveStance()
	return SpellFlashAddon.isForm((GetSpellInfo(71))--[["Defensive Stance"]])
end

function SpellFlashAddon.isBerserkerStance()
	return SpellFlashAddon.isForm((GetSpellInfo(2458))--[["Berserker Stance"]])
end



function SpellFlashAddon.isShieldBlockActive()
	return SpellFlashAddon.checkBuff(nil,nil,nil,nil,nil,nil,nil,"Ability_Defend")
end

function SpellFlashAddon.isBattleShoutActive()
	return SpellFlashAddon.checkBuff(nil,nil,nil,nil,nil,nil,nil,"Ability_Warrior_BattleShout")
end

function SpellFlashAddon.isEnrageActive()
	return SpellFlashAddon.checkBuff(nil,nil,nil,nil,nil,nil,nil,"Spell_Shadow_UnholyFrenzy")
end



-- Returns the number of rage points the Tactical Mastery ability will allow you to keep when you switch stances.
-- Will return 0 if no rank of the ability has been learned.
function SpellFlashAddon.TacticalMasteryRagePoints()
	local t = SpellFlashAddon.GetTalentRank((GetSpellInfo(12295))--[["Tactical Mastery"]])
	return (5 * t)
end

-- Returns the number of rage points the Berserker Rage ability will give.
-- Will return 0 if no rank of the ability has been learned from the Warrior Trainer.
function SpellFlashAddon.BerserkerRageRagePoints()
	if SpellFlashAddon.IsSpellKnown((GetSpellInfo(18499))--[["Berserker Rage"]]) then
		local t = SpellFlashAddon.GetTalentRank((GetSpellInfo(20500))--[["Improved Berserker Rage"]])
		return (5 * t)
	end
	return 0
end

-- Returns the number of rage points the Bloodrage ability will give.
-- Will return 0 if no rank of the ability has been learned from the Warrior Trainer.
function SpellFlashAddon.BloodrageRagePoints()
	if SpellFlashAddon.IsSpellKnown((GetSpellInfo(2687))--[["Bloodrage"]]) then
		local t = SpellFlashAddon.GetTalentRank((GetSpellInfo(12301))--[["Improved Bloodrage"]])
		if t == 2 then
			return 15
		elseif t == 1 then
			return 12
		end
		return 10
	end
	return 0
end







function SpellFlashAddon.Castable.SunderArmor(IfExpirationTimeOrLess)
	local z = {}
	z.SpellName = (GetSpellInfo(7386))--[["Sunder Armor"]]
	z.EnemyTargetNeeded = 1
	if SpellFlashAddon.checkDebuff(z.SpellName,nil,nil,5,IfExpirationTimeOrLess or 10,nil,nil,nil,nil,SpellFlashAddon.GetSpellRank(z.SpellName)) then
		return false
	end
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.UnlimitedSunderArmor()
	return SpellFlashAddon.Castable.SunderArmor(99)
end



function SpellFlashAddon.Castable.BattleStance()
	local z = {}
	z.SpellName = (GetSpellInfo(2457))--[["Battle Stance"]]
	if SpellFlashAddon.WARRIOR.CheckStance(z.SpellName) then
		return false
	end
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.DefensiveStance()
	local z = {}
	z.SpellName = (GetSpellInfo(71))--[["Defensive Stance"]]
	if SpellFlashAddon.WARRIOR.CheckStance(z.SpellName) then
		return false
	end
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.BerserkerStance()
	local z = {}
	z.SpellName = (GetSpellInfo(2458))--[["Berserker Stance"]]
	if SpellFlashAddon.WARRIOR.CheckStance(z.SpellName) then
		return false
	end
	return SpellFlashAddon.CheckIfSpellCastable(z)
end


function SpellFlashAddon.Castable.MortalStrike()
	local z = {}
	z.SpellName = (GetSpellInfo(12294))--[["Mortal Strike"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Bloodthirst()
	local z = {}
	z.SpellName = (GetSpellInfo(23881))--[["Bloodthirst"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Devastate()
	local z = {}
	z.SpellName = (GetSpellInfo(20243))--[["Devastate"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.ShieldSlam()
	local z = {}
	z.SpellName = (GetSpellInfo(23922))--[["Shield Slam"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Slam(EvenIfCasting)
	local z = {}
	z.SpellName = (GetSpellInfo(1464))--[["Slam"]]
	z.EnemyTargetNeeded = 1
	z.EvenIfCasting = EvenIfCasting or SpellFlashAddon.checkBuff((GetSpellInfo(46916))--[["Slam!"]])
	return SpellFlashAddon.CheckIfSpellCastable(z)
end


function SpellFlashAddon.Castable.ConcussionBlow()
	local z = {}
	z.SpellName = (GetSpellInfo(12809))--[["Concussion Blow"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end


function SpellFlashAddon.Castable.VictoryRush()
	local z = {}
	z.SpellName = (GetSpellInfo(34428))--[["Victory Rush"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Charge()
	local z = {}
	z.SpellName = (GetSpellInfo(100))--[["Charge"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Taunt()
	local z = {}
	z.SpellName = (GetSpellInfo(355))--[["Taunt"]]
	if not SpellFlashAddon.isEnemyTargetingFriendButNotYou() then
		return false
	end
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.MockingBlow()
	local z = {}
	z.SpellName = (GetSpellInfo(694))--[["Mocking Blow"]]
	if not SpellFlashAddon.isEnemyTargetingFriendButNotYou() then
		return false
	end
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Intercept()
	local z = {}
	z.SpellName = (GetSpellInfo(20252))--[["Intercept"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Intervene()
	if not UnitIsFriend("player", "target") then
		return false
	end
	local z = {}
	z.SpellName = (GetSpellInfo(3411))--[["Intervene"]]
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Overpower()
	local z = {}
	z.SpellName = (GetSpellInfo(7384))--[["Overpower"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Revenge()
	local z = {}
	z.SpellName = (GetSpellInfo(6572))--[["Revenge"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Cleave()
	if not SpellFlashAddon.WARRIOR.MeleeDistance() then
		return false
	end
	local z = {}
	z.SpellName = (GetSpellInfo(845))--[["Cleave"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Whirlwind()
	if not SpellFlashAddon.WARRIOR.MeleeDistance() then
		return false
	end
	local z = {}
	z.SpellName = (GetSpellInfo(1680))--[["Whirlwind"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.SweepingStrikes()
	if not SpellFlashAddon.isMainHandEquipped() then
		return false
	end
	if not SpellFlashAddon.WARRIOR.MeleeDistance() then
		return false
	end
	local z = {}
	z.SpellName = (GetSpellInfo(12328))--[["Sweeping Strikes"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Rend()
	local z = {}
	z.SpellName = (GetSpellInfo(772))--[["Rend"]]
	z.DebuffName = z.SpellName
	z.DebuffSlotNeeded = 1
	z.IsMine = 1
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Disarm()
	local z = {}
	z.SpellName = (GetSpellInfo(676))--[["Disarm"]]
	z.DebuffName = z.SpellName
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Hamstring()
	local z = {}
	z.SpellName = (GetSpellInfo(1715))--[["Hamstring"]]
	z.DebuffName = z.SpellName
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Execute()
	local z = {}
	z.SpellName = (GetSpellInfo(5308))--[["Execute"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.ThunderClap()
	if not SpellFlashAddon.WARRIOR.MeleeDistance() then
		return false
	end
	local z = {}
	z.SpellName = (GetSpellInfo(6343))--[["Thunder Clap"]]
	z.DebuffName = z.SpellName
	z.NoRangeCheck = 1
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.ShieldBash()
	if not SpellFlashAddon.isCastingOrChanneling(nil,nil,"target") then
		return false
	end
	local z = {}
	z.SpellName = (GetSpellInfo(72))--[["Shield Bash"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Pummel()
	if not SpellFlashAddon.isCastingOrChanneling(nil,nil,"target") then
		return false
	end
	local z = {}
	z.SpellName = (GetSpellInfo(6552))--[["Pummel"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.ShieldBlock()
	if not SpellFlashAddon.isEnemyTargetingYou() or not SpellFlashAddon.WARRIOR.MeleeDistance() then
		return false
	end
	local z = {}
	z.SpellName = (GetSpellInfo(2565))--[["Shield Block"]]
	z.BuffName = z.SpellName
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.SpellReflection()
	if not SpellFlashAddon.isCasting(nil,nil,"target") or not SpellFlashAddon.isEnemyTargetingYou() then
		return false
	end
	local z = {}
	z.SpellName = (GetSpellInfo(23920))--[["Spell Reflection"]]
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.HeroicStrike()
	if not SpellFlashAddon.WARRIOR.MeleeDistance() then
		return false
	end
	local z = {}
	z.SpellName = (GetSpellInfo(78))--[["Heroic Strike"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.DemoralizingShout()
	if not CheckInteractDistance("target", 3) then
		return false
	end
	local z = {}
	z.SpellName = (GetSpellInfo(1160))--[["Demoralizing Shout"]]
	z.DebuffName = z.SpellName
	z.EnemyTargetNeeded = 1
	z.NoRangeCheck = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.PiercingHowl()
	if not CheckInteractDistance("target", 3) then
		return false
	end
	local z = {}
	z.SpellName = (GetSpellInfo(12323))--[["Piercing Howl"]]
	z.DebuffName = z.SpellName
	z.EnemyTargetNeeded = 1
	z.NoRangeCheck = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.BattleShout()
	local z = {}
	z.SpellName = (GetSpellInfo(6673))--[["Battle Shout"]]
	z.BuffName = z.SpellName
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.CommandingShout()
	local z = {}
	z.SpellName = (GetSpellInfo(469))--[["Commanding Shout"]]
	z.BuffName = z.SpellName
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.BerserkerRage()
	local z = {}
	z.SpellName = (GetSpellInfo(18499))--[["Berserker Rage"]]
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.Bloodrage()
	local z = {}
	z.SpellName = (GetSpellInfo(2687))--[["Bloodrage"]]
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.DeathWish()
	local z = {}
	z.SpellName = (GetSpellInfo(12292))--[["Death Wish"]]
	z.EnemyTargetNeeded = 1
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.LastStand()
	if SpellFlashAddon.HealthDamagePercent("player") < 30 then
		return false
	end
	local z = {}
	z.SpellName = (GetSpellInfo(12975))--[["Last Stand"]]
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.EnragedRegeneration()
	if SpellFlashAddon.HealthDamagePercent("player") < 30 then
		return false
	end
	local z = {}
	z.SpellName = (GetSpellInfo(55694))--[["Enraged Regeneration"]]
	return SpellFlashAddon.CheckIfSpellCastable(z)
end

function SpellFlashAddon.Castable.ShieldWall()
	if not SpellFlashAddon.isEnemyTargetingYou() then
		return false
	end
	local z = {}
	z.SpellName = (GetSpellInfo(871))--[["Shield Wall"]]
	return SpellFlashAddon.CheckIfSpellCastable(z)
end



function SpellFlashAddon.WARRIOR.MeleeDistance()
	local m =  (
		(GetSpellInfo((GetSpellInfo(772))--[["Rend"]])) or
		(GetSpellInfo((GetSpellInfo(1715))--[["Hamstring"]])) or
		(GetSpellInfo((GetSpellInfo(7386))--[["Sunder Armor"]])) or
		(GetSpellInfo((GetSpellInfo(7384))--[["Overpower"]])) or
		(GetSpellInfo((GetSpellInfo(6572))--[["Revenge"]])) or
		(GetSpellInfo((GetSpellInfo(6552))--[["Pummel"]])) or
		(GetSpellInfo((GetSpellInfo(72))--[["Shield Bash"]])) or
		(GetSpellInfo((GetSpellInfo(5308))--[["Execute"]])) or
		(GetSpellInfo((GetSpellInfo(12294))--[["Mortal Strike"]])) or
		(GetSpellInfo((GetSpellInfo(23881))--[["Bloodthirst"]])) or
		(GetSpellInfo((GetSpellInfo(23922))--[["Shield Slam"]])) or
		(GetSpellInfo((GetSpellInfo(20243))--[["Devastate"]])) or
		(GetSpellInfo((GetSpellInfo(12809))--[["Concussion Blow"]])) or
		(GetSpellInfo((GetSpellInfo(34428))--[["Victory Rush"]])) or
		(GetSpellInfo((GetSpellInfo(1464))--[["Slam"]])) or
		(GetSpellInfo((GetSpellInfo(694))--[["Mocking Blow"]])) or
		(GetSpellInfo((GetSpellInfo(676))--[["Disarm"]]))
	)
	if m then
		if IsSpellInRange(m,"target") ~= 1 then
			return false
		end
	elseif not CheckInteractDistance("target", 3) then
		return false
	end
	return true
end
